@@ -35,6 +35,11 @@ function(data, compute, variable, by=NULL, by_cols=NULL, rows=NULL,
   # subset any specified rows of input data frame
   if (!missing(rows)) {  # subset rows
     r <- eval(substitute(rows), envir=data, enclos=parent.frame())
+    if (!any(r)) {
+      cat("\n"); stop(call.=FALSE, "\n","------\n",
+        "No rows of data with the specified value of\n",
+        "rows = ", deparse(substitute(rows)), "\n\n")
+    }
     r <- r & !is.na(r)  # set missing for a row to FALSE
     data <- data[r,,drop=FALSE]
   }
